package ru.ldeloff.servermonitorbot.commands.cpu.temp.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import ru.ldeloff.servermonitorbot.commands.CommandTemplate;
import ru.ldeloff.servermonitorbot.service.MessagingService;
import ru.ldeloff.servermonitorbot.util.UpdateUtil;
import ru.ldeloff.servermonitorbot.model.SshCommand;
import ru.ldeloff.servermonitorbot.model.server.SshServer;
import ru.ldeloff.servermonitorbot.service.SshService;
import ru.ldeloff.servermonitorbot.view.ServerListButtons;

import java.util.Objects;
import java.util.Optional;

@Service
@Slf4j
public class CpuTemp extends CommandTemplate {

    public CpuTemp(UpdateUtil updateUtil, ServerListButtons serverListButtons, SshService sshService, MessagingService messagingService) {
        super(updateUtil, serverListButtons, sshService, messagingService);
        setName("CPU.temp");
    }

    @Override
    public String executeCommandSpecificHost(String serverName) {
        Optional<SshServer> server = sshService.getAllSshServers()
                .stream()
                .filter(x -> x.getName().equals(serverName))
                .findFirst();
        if (server.isPresent()) {
            SshCommand result = sshService.execute(new SshCommand("cat /sys/class/thermal/thermal_zone0/temp", 100, server.get()));
            return server.get().getName() + ": \n" +
                    (Objects.isNull(result.getResponse()) ? "ошибка при выполнении команды" :
                            String.format("%.1f",
                                    Double.parseDouble(result.getResponse().replaceAll("\n", ""))/1000))
                    + "°C";
        } else {
            log.error("Ошибка при выполнении команды 'CPUtemp'. Искомый сервер ({}) не найден", serverName);
            return null;
        }
    }
}
