package ru.ldeloff.servermonitorbot.commands.hdd.mdadm.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import ru.ldeloff.servermonitorbot.commands.CommandTemplate;
import ru.ldeloff.servermonitorbot.service.MessagingService;
import ru.ldeloff.servermonitorbot.util.UpdateUtil;
import ru.ldeloff.servermonitorbot.model.SshCommand;
import ru.ldeloff.servermonitorbot.model.server.SshServer;
import ru.ldeloff.servermonitorbot.service.SshService;
import ru.ldeloff.servermonitorbot.view.ServerListButtons;

import java.util.*;

@Service
@Slf4j
public class MdadmStatus extends CommandTemplate {

    public MdadmStatus(UpdateUtil updateUtil, ServerListButtons serverListButtons, SshService sshService, MessagingService messagingService) {
        super(updateUtil, serverListButtons, sshService, messagingService);
        setName("MDADM");
    }

    @Override
    public String executeCommandSpecificHost(String serverName) {
        Optional<SshServer> server = sshService.getAllSshServers()
                .stream()
                .filter(x -> x.getName().equals(serverName))
                .findFirst();
        if (server.isPresent()) {
            // узнаю скок рейдов
            SshCommand sshCommandRaid = sshService.execute(new SshCommand("mdadm --detail --scan", 500, server.get()));
            List<String> raidNames = parseRaidNames(sshCommandRaid);
            // Для каждого рейда надо выяснить статус
            StringBuilder result = new StringBuilder();
            raidNames.forEach(raid -> {
                result.append(raid).append(":\n");
                SshCommand sshCommandHdd = sshService.execute(new SshCommand("mdadm --detail " + raid, 500, server.get()));
                List<String> hdds = parseHddState(sshCommandHdd);
                hdds.forEach(hdd -> result.append(hdd).append("\n"));
            });
            return server.get().getName() + ": \n" + result;
        } else {
            log.error("Ошибка при выполнении команды 'mdadm'. Искомый сервер ({}) не найден", serverName);
            return null;
        }
    }

    private List<String> parseRaidNames(SshCommand result) {
        List<String> names = new ArrayList<>();
        Arrays.stream(result.getResponse().split("\n"))
                .map(line -> line.split(" "))
                .filter(lineArray -> lineArray.length >= 2)
                .map(lineArray -> lineArray[1])
                .forEach(names::add);
        return names;
    }

    private List<String> parseHddState(SshCommand result) {
        List<String> names = new ArrayList<>();
        names.add("Number Name State");

        String[] lines = result.getResponse().split("\n");

        boolean foundHeader = false;

        for (String line : lines) {
            if (!foundHeader) {
                if ( line.contains("Number") &&
                        line.contains("Major") &&
                        line.contains("Minor") &&
                        line.contains("RaidDevice") )  {
                    foundHeader = true;
                }
            } else {
                List<String> elements = Arrays.stream(line.split(" "))
                        .filter(x -> !Objects.equals(x, "")).toList();

                names.add(elements.get(0) + ", "
                        + elements.get(6) + ", "
                        + elements.get(4) + " "
                        + elements.get(5));
            }
        }
        return names;
    }
}
