package ru.ldeloff.servermonitorbot.commands.uname.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import ru.ldeloff.servermonitorbot.commands.CommandTemplate;
import ru.ldeloff.servermonitorbot.service.MessagingService;
import ru.ldeloff.servermonitorbot.util.UpdateUtil;
import ru.ldeloff.servermonitorbot.model.SshCommand;
import ru.ldeloff.servermonitorbot.model.server.SshServer;
import ru.ldeloff.servermonitorbot.service.SshService;
import ru.ldeloff.servermonitorbot.view.ServerListButtons;

import java.util.Objects;
import java.util.Optional;

@Service
@Slf4j
public class Uname extends CommandTemplate {

    public Uname(UpdateUtil updateUtil, ServerListButtons serverListButtons, SshService sshService, MessagingService messagingService) {
        super(updateUtil, serverListButtons, sshService, messagingService);
        setName("uname");
    }

    @Override
    public String executeCommandSpecificHost(String serverName) {
        Optional<SshServer> server = sshService.getAllSshServers()
                .stream()
                .filter(x -> x.getName().equals(serverName))
                .findFirst();
        if (server.isPresent()) {
            SshCommand result = sshService.execute(new SshCommand("uname -a", 100, server.get()));
            return server.get().getName() + ": " +
                    (Objects.isNull(result.getResponse()) ? "ошибка при выполнении команды" : result.getResponse());
        } else {
            log.error("Ошибка при выполнении команды 'uname'. Искомый сервер ({}) не найден", serverName);
            return null;
        }
    }
}
