package ru.ldeloff.servermonitorbot.controller;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.telegram.telegrambots.bots.TelegramLongPollingBot;
import org.telegram.telegrambots.meta.api.objects.Message;
import org.telegram.telegrambots.meta.api.objects.Update;
import ru.ldeloff.servermonitorbot.model.TelegramBot;
import ru.ldeloff.servermonitorbot.service.SshService;
import ru.ldeloff.servermonitorbot.commands.CommandTemplate;
import ru.ldeloff.servermonitorbot.view.SwitchToMainMenu;

import java.util.Map;

@Service
@RequiredArgsConstructor
public class TelegramBotController extends TelegramLongPollingBot {

    private final Map<String, CommandTemplate> commands;

    private final TelegramBot telegramBot;
    private final SwitchToMainMenu switchToMainMenu;
    private final SshService sshService;


    @Override
    public void onUpdateReceived(Update update) {
        boolean result = false;
        for (Map.Entry<String, CommandTemplate> entry : commands.entrySet()) {
            result = entry.getValue().execute(update);
            if (result) {
                break;
            }
        }
        if (!result) {
            Message message = update.getMessage();
            if (message!=null) {
                message.setText("Not found");
            }
            update.setMessage(message);
            switchToMainMenu.execute(update);
        }
    }

    @Override
    public String getBotUsername() {
        return telegramBot.getBotUsername();
    }

    @Override
    public String getBotToken() {
        return telegramBot.getBotToken();
    }

    @Override
    public void onClosing() {
        super.onClosing();
        sshService.disconnectAllConnections();
    }
}
