package ru.ldeloff.servermonitorbot.init;

import lombok.NoArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;
import org.telegram.telegrambots.meta.TelegramBotsApi;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.exceptions.TelegramApiException;
import org.telegram.telegrambots.updatesreceivers.DefaultBotSession;
import ru.ldeloff.servermonitorbot.controller.TelegramBotController;
import ru.ldeloff.servermonitorbot.model.user.User;
import ru.ldeloff.servermonitorbot.service.MessagingService;
import ru.ldeloff.servermonitorbot.service.UserService;
import ru.ldeloff.servermonitorbot.view.TelegramBotKeyboard;


@Slf4j
@Component
@NoArgsConstructor
@Order(1)
public class StartBot implements ApplicationRunner {
    private TelegramBotController telegramBot;
    private TelegramBotKeyboard telegramBotKeyboard;
    private UserService userService;
    private MessagingService messagingService;

    @Autowired
    public StartBot(TelegramBotController telegramBot, TelegramBotKeyboard telegramBotKeyboard, UserService userService, MessagingService messagingService) {
        this.telegramBot = telegramBot;
        this.telegramBotKeyboard = telegramBotKeyboard;
        this.userService = userService;
    }
    @Override
    public void run(ApplicationArguments args) {
        try {
            TelegramBotsApi botsApi = new TelegramBotsApi(DefaultBotSession.class);
            botsApi.registerBot(telegramBot);
            userService.getAllUsers().forEach(this::sendInitMessage);
            log.info("Бот запущен");
        } catch (TelegramApiException e) {
            log.error(e.getMessage());
        }
    }
    private void sendInitMessage(User user) {
        SendMessage answer = new SendMessage();
        answer.setChatId(user.getTelegramId());
        answer.setText("Бот перезапущен");
        messagingService.send(telegramBotKeyboard.uiForm(answer));
    }
}
