package ru.ldeloff.servermonitorbot.util;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.telegram.telegrambots.meta.api.objects.Update;
import ru.ldeloff.servermonitorbot.model.user.Role;
import ru.ldeloff.servermonitorbot.model.user.User;
import ru.ldeloff.servermonitorbot.service.UserService;

import java.util.List;

@Service
@RequiredArgsConstructor
public class UpdateUtil {

    private final UserService userService;

    public User getUser(Update update) {
        long id = -1L;
        String login = null;
        if (update.hasMessage()) {
            id = update.getMessage().getChat().getId();
            login = update.getMessage().getChat().getUserName();
        } else if (update.hasCallbackQuery()) {
            id = update.getCallbackQuery().getMessage().getChatId();
            login = update.getCallbackQuery().getFrom().getUserName();
        }
        User user = userService.getByTelegramId(id);
        if (user == null) {
            user = new User();
            user.setTelegramId(id);
            user.setRole(Role.ANONYMOUS);
        }
        user.setLogin(login);
        return user;
    }

    public String getMessage(Update update) {
        if (update.hasMessage()) {
            return update.getMessage().getText();
        } else if (update.hasCallbackQuery()) {
            return update.getCallbackQuery().getData();
        }
        return "";
    }

    public boolean roleChecker(Update update, List<Role> expectedRoles) {
        User user = getUser(update);
        return expectedRoles.contains(user.getRole());
    }
}
