package ru.ldeloff.servermonitorbot.view;

import lombok.RequiredArgsConstructor;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.ReplyKeyboardMarkup;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.buttons.KeyboardButton;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.buttons.KeyboardRow;
import ru.ldeloff.servermonitorbot.model.user.Role;
import ru.ldeloff.servermonitorbot.model.user.User;
import ru.ldeloff.servermonitorbot.service.UserService;
import ru.ldeloff.servermonitorbot.commands.CommandTemplate;


import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import static ru.ldeloff.servermonitorbot.model.user.Role.ADMIN;
import static ru.ldeloff.servermonitorbot.model.user.Role.USER;

@Component
@RequiredArgsConstructor
public class TelegramBotKeyboard implements UiFormer {

    private final UserService userService;
    private final ApplicationContext applicationContext;

    @Override
    public SendMessage uiForm(SendMessage message) {
        ReplyKeyboardMarkup replyKeyboardMarkup = new ReplyKeyboardMarkup();
        replyKeyboardMarkup.setResizeKeyboard(true);
        replyKeyboardMarkup.setOneTimeKeyboard(false);

        String chatId = message.getChatId();
        User user = userService.getByTelegramId(Long.parseLong(chatId));

        ArrayList<KeyboardRow> keyboardRows = formKeyboard(user);
        replyKeyboardMarkup.setKeyboard(keyboardRows);
        message.setReplyMarkup(replyKeyboardMarkup);
        return message;
    }

    private ArrayList<KeyboardRow> formKeyboard(User user) {
        Role role = user.getRole();
        Map<String, CommandTemplate> commands = applicationContext.getBeansOfType(CommandTemplate.class);
        if (List.of(ADMIN, USER).contains(role)) {
            commands.remove("/start");
            commands.remove("Not found");
        }
        int buttonOnLine = 3;

        ArrayList<KeyboardRow> keyboardRows = new ArrayList<>();
        KeyboardRow keyboardRow = new KeyboardRow();

        for (Map.Entry<String, CommandTemplate> entry : commands.entrySet()) {
            if (entry.getValue().getExpectedRole().contains(role)) {
                keyboardRow.add(new KeyboardButton(entry.getValue().getName()));
            }
            if (keyboardRow.size()>=buttonOnLine) {
                keyboardRows.add(keyboardRow);
                keyboardRow = new KeyboardRow();
            }
        }
        if (!keyboardRow.isEmpty()) {
            keyboardRows.add(keyboardRow);
        }
        return keyboardRows;
    }
}
